@@ -43,18 +43,13 @@ The only onterface function is iter_avro, example usage::
         writer(out, schema, records)
 '''
 
-__version_info__ = (0, 14, 11)
+__version_info__ = (0, 16, 3)
 __version__ = '%s.%s.%s' % __version_info__
 
 
-try:
-    from . import _reader
-    from . import _writer
-    from . import _schema
-except ImportError as e:
-    from . import reader as _reader
-    from . import writer as _writer
-    from . import schema as _schema
+from . import reader as _reader
+from . import writer as _writer
+from . import schema as _schema
 
 
 def _acquaint_schema(schema):
